**************************************
* This program creates Table 1
**************************************

* Preliminary setup -- check packages
capture log close
log using do_tables.log, text replace
net install outreg2, from(http://fmwww.bc.edu/RePEc/bocode/o)

* Set directory path -- to where DTA and DO files are.
cd "U:\_store_work\Perceived-Multipliers\Analysis\STATA\WP archive"

*****************************************
* Read in data
*****************************************

clear
clear matrix
set more off
set mem 500m
set more off
use dta.dta

*****************************************
* Set up baseline sample
*****************************************

gen sample=1 if (eu==1|wdicode=="CHE"|wdicode=="ISL"|wdicode=="NOR")

*****************************************
* Table 1. Main Results
*****************************************

preserve
* Settings
local title = "Baseline"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x, r
* Store results in outreg table
	outreg2 using T1.xls, ///
	ctitle("`title'") bdec(3) ///
	replace
restore

preserve
* Settings
local title = "Filling missing using EC forecasts"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
bys ifscode: replace x = eefgsb2010spring-eefgsb2010spring[_n-2] if x==.
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x, r
* Store results in outreg table
	outreg2 using T1.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Excluding IMF programs"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Sample
keep if year==2011
keep if sample==1
drop if (wdicode=="GRC"|wdicode=="IRL"|wdicode=="ISL"|wdicode=="LVA"|wdicode=="PRT"|wdicode=="ROM")
* Regression
reg y x, r
* Store results in outreg table
	outreg2 using T1.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Excluding Emerging Europe"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Sample
keep if year==2011
keep if sample==1
drop if weoadv~=1
* Regression
reg y x, r
* Store results in outreg table
	outreg2 using T1.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Excluding 2 largest policy changes"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Sample
keep if year==2011
keep if sample==1
drop if (wdicode=="DEU"|wdicode=="GRC")
* Regression
reg y x, r
* Store results in outreg table
	outreg2 using T1.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Outliers: Robust regression"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Sample
keep if year==2011
keep if sample==1
* Regression
rreg y x
* Store results in outreg table
	outreg2 using T1.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Outliers: Quantile regression"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Sample
keep if year==2011
keep if sample==1
* Regression
qreg y x
local r2 = 1- (`=e(sum_adev)'/`=e(sum_rdev)')
* Store results in outreg table
	outreg2 using T1.xls, ///
	addstat("R-squared", `r2') ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Outliers: Cook's Distance"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x
predict cookcheck, cooksd
gsort -cookcheck
reg y x if cookcheck<=(4/e(N)), r
* Store results in outreg table
	outreg2 using T1.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "All available (AEs)"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Sample
keep if year==2011
keep if (eu==1|weoadv==1)
* Regression
reg y x, r
* Store results in outreg table
	outreg2 using T1.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Economies in liquidity trap"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Sample
keep if year==2011
keep if (eu==1|weoadv==1)
drop if (wdicode=="AUS"|wdicode=="HKG"|wdicode=="HUN"|wdicode=="ISL"|wdicode=="ISR"|wdicode=="KOR"|wdicode=="NZL"|wdicode=="NOR"|wdicode=="POL"|wdicode=="ROM"|wdicode=="SGP"|wdicode=="SWE"|wdicode=="TWN")
* Regression
reg y x, r
* Store results in outreg table
	outreg2 using T1.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Outliers: Robust regression"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Sample
keep if year==2011
keep if (eu==1|weoadv==1)
* Regression
rreg y x
* Store results in outreg table
	outreg2 using T1.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Outliers: Quantile regression"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Sample
keep if year==2011
keep if (eu==1|weoadv==1)
* Regression
qreg y x
local r2 = 1- (`=e(sum_adev)'/`=e(sum_rdev)')
* Store results in outreg table
	outreg2 using T1.xls, ///
	addstat("R-squared", `r2') ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Outliers: Cook's Distance"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Sample
keep if year==2011
keep if (eu==1|weoadv==1)
* Regression
reg y x
predict cookcheck, cooksd
gsort -cookcheck
reg y x if cookcheck<=(4/e(N)), r
* Store results in outreg table
	outreg2 using T1.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "All available (EMs)"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Sample
keep if year==2011
keep if (eu~=1 & weoadv~=1)
* Regression
reg y x, r
* Store results in outreg table
	outreg2 using T1.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Outliers: Robust regression"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Sample
keep if year==2011
keep if (eu~=1 & weoadv~=1)
* Regression
rreg y x
* Store results in outreg table
	outreg2 using T1.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Outliers: Quantile regression"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Sample
keep if year==2011
keep if (eu~=1 & weoadv~=1)
* Regression
qreg y x
local r2 = 1- (`=e(sum_adev)'/`=e(sum_rdev)')
* Store results in outreg table
	outreg2 using T1.xls, ///
	addstat("R-squared", `r2') ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "Outliers: Cook's Distance"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Sample
keep if year==2011
keep if (eu~=1 & weoadv~=1)
* Regression
reg y x
predict cookcheck, cooksd
gsort -cookcheck
reg y x if cookcheck<=(4/e(N)), r
* Store results in outreg table
	outreg2 using T1.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore


log close

