**************************************
* This program creates Table 7
**************************************

* Preliminary setup -- check packages
capture log close
log using do_tables.log, text replace
net install outreg2, from(http://fmwww.bc.edu/RePEc/bocode/o)

* Set directory path -- to where DTA and DO files are.
cd "U:\_store_work\Perceived-Multipliers\Analysis\STATA\WP archive"

*****************************************
* Read in data
*****************************************

clear
clear matrix
set more off
set mem 500m
set more off
use dta.dta

*****************************************
* Set up baseline sample
*****************************************

gen sample=1 if (eu==1|wdicode=="CHE"|wdicode=="ISL"|wdicode=="NOR")

*****************************************
* Table 7. Europe: Alternative Forecasters
*****************************************

preserve
* Settings
local title = "IMF"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x, r
* Store results in outreg table
	outreg2 using T7.xls, ///
	ctitle("`title'") bdec(3) ///
	replace
restore

preserve
* Settings
local title = "EU Commission"
* Variables
bys ifscode: gen y = 100*((1+eefgrowth2012spring/100)*(1+eefgrowth2012spring[_n-1]/100)-1)  -  100*((1+eefgrowth2010spring/100)*(1+eefgrowth2010spring[_n-1]/100)-1)
bys ifscode: gen x = eefgsb2010spring-eefgsb2010spring[_n-2]
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x, r
* Store results in outreg table
	outreg2 using T7.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "OECD"
* Variables
bys ifscode: gen y = 100*(  ((gdpv2012june/gdpv2012june[_n-2])) - 1 )  -  100*(  ((gdpv2010june/gdpv2010june[_n-2])) - 1 )
bys ifscode: gen x = nlgqu2010june-nlgqu2010june[_n-2]
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x, r
* Store results in outreg table
	outreg2 using T7.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

preserve
* Settings
local title = "EIU"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+eiugrowth2010spring/100)*(1+eiugrowth2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y x, r
* Store results in outreg table
	outreg2 using T7.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

*****************************************

* Equalized sample

* IMF vs. others
preserve
* Variables
bys ifscode: gen y1 = 100*((1+ngdp_rpch2012spring/100)*(1+ngdp_rpch2012spring[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x1 = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
bys ifscode: gen y2 = 100*((1+eefgrowth2012spring/100)*(1+eefgrowth2012spring[_n-1]/100)-1)  -  100*((1+eefgrowth2010spring/100)*(1+eefgrowth2010spring[_n-1]/100)-1)
bys ifscode: gen x2 = eefgsb2010spring-eefgsb2010spring[_n-2]
bys ifscode: gen y3 = 100*(  ((gdpv2012june/gdpv2012june[_n-2])) - 1 )  -  100*(  ((gdpv2010june/gdpv2010june[_n-2])) - 1 )
bys ifscode: gen x3 = nlgqu2010june-nlgqu2010june[_n-2]
bys ifscode: gen y4 = 100*((1+ngdp_rpch2012spring/100)*(1+ngdp_rpch2012spring[_n-1]/100)-1)  -  100*((1+eiugrowth2010spring/100)*(1+eiugrowth2010spring[_n-1]/100)-1)
bys ifscode: gen x4 = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Sample:
keep if sample==1
keep if year==2011
* Equalize sample
keep if (x1~=. & x2~=. & x3~=. & x4~=.)
keep if (y1~=. & y2~=. & y3~=. & x4~=.)
* Regressions:
local title = "IMF"
gen y = y1
gen x = x1
reg y x, r
	outreg2 using T7.xls, ///
	ctitle("`title'") bdec(3) ///
	append
local title = "EU Commission"
replace y = y2
replace x = x2
reg y x, r
	outreg2 using T7.xls, ///
	ctitle("`title'") bdec(3) ///
	append
local title = "OECD"
replace y = y3
replace x = x3
reg y x, r
	outreg2 using T7.xls, ///
	ctitle("`title'") bdec(3) ///
	append
local title = "EIU"
replace y = y4
replace x = x4
reg y x, r
	outreg2 using T7.xls, ///
	ctitle("`title'") bdec(3) ///
	append
restore

log close

