**************************************
* This conducts the additional analysis
* cited in footnotes.
**************************************

* Preliminary setup -- check packages
capture log close
log using do_tables.log, text replace
net install outreg2, from(http://fmwww.bc.edu/RePEc/bocode/o)

* Set directory path -- to where DTA and DO files are.
cd "U:\_store_work\Perceived-Multipliers\Analysis\STATA\WP archive"

*****************************************
* Read in data
*****************************************

clear
clear matrix
set more off
set mem 500m
set more off
use dta.dta

*****************************************
* Set up baseline sample
*****************************************

gen sample=1 if (eu==1|wdicode=="CHE"|wdicode=="ISL"|wdicode=="NOR")

*****************************************
* Footnote 12. 
* Constant term interpretation
*****************************************

preserve
* Variables
sort ifscode year
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Sample:
keep if sample==1
keep if year==2011
* Regressions:
reg y x, r
sum y if e(sample)
local ybar = r(mean)
sum x if e(sample)
local xbar = r(mean)
lincom `ybar' - _b[x]*`xbar'
reg y if e(sample), r
reg x if e(sample), r
restore

*****************************************
* Footnote 12. 
* Expressing fiscal consolidation in percent of headline (not potential) GDP.
* "We express the structural balance as a ratio to potential GDP, but results based on the structural balance expressed as a ratio to nominal GDP are very similar."
*****************************************

preserve
* Variables
sort ifscode year
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = (ggsb_gdp2010spring/(1+(ngap2010spring/100)))   -   (ggsb_gdp2010spring[_n-2]/(1+(ngap2010spring[_n-2]/100)))
* Sample:
keep if sample==1
keep if year==2011
* Regressions:
reg y x, r
restore

*****************************************
* Footnote 14. 
* Test null: coefficient equal for 
* euro peg / non-euro peg economies
*****************************************

preserve
* Variables
sort ifscode year
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Interactions:
bys ifscode: gen w = 1
bys ifscode: replace w = 0 if (euro==1) | (wdicode=="BGR"|wdicode=="DNK"|wdicode=="LVA"|wdicode=="LTU")
bys ifscode: gen i = x*w
* Sample:
keep if sample==1
keep if year==2011
* Regressions:
reg y x w i, r
test i
restore

*****************************************
* Footnote 19. 
* Outlier residual weights
*****************************************

* Outliers
preserve
* Variables
sort ifscode year
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Sample:
keep if (eu==1|weoadv==1)
keep if year==2011
* Robust Regression (rreg)
rreg y x, genwt(w)
sort w
predict r if e(sample), resid
* List observations with smallest WLS weight, "w" (largest absolute residuals "r" )
clist wdicode w r in 1/5 if e(sample), noobs
restore

*****************************************
* Footnote 27. 
* Forecast error of fiscal consolidation:
* regression on forecast of fiscal
* consolidation
*****************************************

preserve
* Variables
sort ifscode year
bys ifscode: gen x = ggsb_gdp2012fall-ggsb_gdp2012fall[_n-2]
bys ifscode: gen z = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
bys ifscode: gen w = x - z 
* Sample:
keep if year==2011
keep if sample==1
* Regressions:
reg w z, r
restore

*****************************************
/*
* Footnote 39. 
"In response to comments on an earlier version of this paper (EC, 2012), 
we also reestimate equation (1) while allowing the coefficients to be 
different for the group of economies that, in ex-post terms, undertook fiscal stimulus in 
2010 and fiscal consolidation in 2011."
*/
*****************************************

preserve
* Variables
sort ifscode year
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen x = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
* Interactions:
bys ifscode: gen w = 0
bys ifscode: replace w = 1 if (ggsb_gdp2012fall[_n-1]-ggsb_gdp2012fall[_n-2]<0) & (ggsb_gdp2012fall-ggsb_gdp2012fall[_n-1]>0) 
bys ifscode: gen i = x*w
* Sample:
keep if sample==1
keep if year==2011
* Regressions and test of null: slope coefficient equal for the two groups
reg y x w i, r
tab wdicode if w==1
lincom _b[x]+_b[i]
test i
restore


log close
